@@ -6,10 +6,8 @@ use strict;
 use warnings;
 use charnames ':full';
 use parent 'Exporter';
-use Unicode::CaseFold qw( fc );
-use Unicode::Normalize qw( NFC );
 
-our $VERSION   = '0.03';
+our $VERSION   = '0.04';
 our @EXPORT_OK = qw( stem stem_fa );
 
 *stem_fa = \&stem;
@@ -17,7 +15,6 @@ our @EXPORT_OK = qw( stem stem_fa );
 sub stem {
     my ($word) = @_;
 
-    $word = NFC fc $word;
     $word = remove_kasra($word);
     $word = remove_suffix($word);
     $word = remove_kasra($word);
@@ -28,10 +25,10 @@ sub stem {
 sub remove_kasra {
     my ($word) = @_;
 
-    if (length $word > 4) {
-        return $word
-            if $word =~ s{ \N{ARABIC KASRA} $}{}x;
-    }
+    return $word
+        if length $word < 5;
+
+    $word =~ s{ \N{ARABIC KASRA} $}{}x;
 
     return $word;
 }
@@ -101,7 +98,7 @@ Lingua::Stem::UniNE::FA - Persian stemmer
 
 =head1 VERSION
 
-This document describes Lingua::Stem::UniNE::FA v0.03.
+This document describes Lingua::Stem::UniNE::FA v0.04.
 
 =head1 SYNOPSIS
 
@@ -124,7 +121,11 @@ stem.
 
 L<Lingua::Stem::UniNE> provides a stemming object with access to all of the
 implemented University of Neuchâtel stemmers including this one.  It has
-additional features like stemming lists or array references of words.
+additional features like stemming lists of words.
+
+L<Lingua::Stem::Any> provides a unified interface to any stemmer on CPAN,
+including this one, as well as additional features like normalization,
+casefolding, and in-place stemming.
 
 This stemming algorithm was originally implemented by Ljiljana Dolamic in
 L<Java|http://members.unine.ch/jacques.savoy/clef/persianStemmerUnicode.txt>.
